@@ -131,7 +131,7 @@ def show_sets_filter(response):
     sets = [] # Need for return at the end
 
     for node in response['data']['event']['sets']['nodes']:
-        if len(node['slots']) == 1:
+        if len(node['slots']) < 2:
             continue # This fixes a bug where player doesn't have an opponent
         if (node['slots'][0]['entrant'] is None or node['slots'][1]['entrant'] is None):
             continue # This fixes a bug when tournament ends early
